@@ -46,8 +46,7 @@ namespace rak {
 // Don't convert negative Timer to timeval and then back to Timer, that will bork.
 class timer {
  public:
-  timer() : m_time(0) {}
-  timer(int64_t usec) : m_time(usec) {}
+  timer(int64_t usec = 0) : m_time(usec) {}
   timer(timeval tv) : m_time((int64_t)(uint32_t)tv.tv_sec * 1000000 + (int64_t)(uint32_t)tv.tv_usec % 1000000) {}
 
   int32_t             seconds() const                    { return m_time / 1000000; }
