@@ -114,6 +114,10 @@ apply_d_change_link(int changeType, core::Download* download, const torrent::Obj
     target = rpc::call_command_string("d.get_base_path", rpc::make_target(download));
     link = rak::path_expand(prefix + rpc::call_command_string("d.get_base_filename", rpc::make_target(download)) + postfix);
 
+//   } else if (type == "directory_path") {
+//     target = rpc::call_command_string("d.get_directory", rpc::make_target(download));
+//     link = rak::path_expand(prefix + rpc::call_command_string("d.get_base_path", rpc::make_target(download)) + postfix);
+
   } else if (type == "tied") {
     link = rak::path_expand(rpc::call_command_string("d.get_tied_to_file", rpc::make_target(download)));
 
@@ -294,6 +298,9 @@ torrent::Object
 retrieve_d_bitfield(core::Download* download) {
   const torrent::Bitfield* bitField = download->download()->file_list()->bitfield();
 
+  if (bitField->empty())
+    return torrent::Object("");
+
   return torrent::Object(rak::transform_hex(bitField->begin(), bitField->end()));
 }
 
@@ -303,7 +310,7 @@ cmd_d_initialize_logs(core::Download* download) {
   download->download()->signal_network_log(sigc::mem_fun(control->core(), &core::Manager::push_log_complete));
   download->download()->signal_storage_error(sigc::mem_fun(control->core(), &core::Manager::push_log_complete));
 
-  if (!rpc::call_command_string("get_tracker_dump").empty())
+  if (!rpc::call_command_string("get_log.tracker").empty())
     download->download()->signal_tracker_dump(sigc::ptr_fun(&core::receive_tracker_dump));
 
   return torrent::Object();
