@@ -385,6 +385,7 @@ apply_scgi(const std::string& arg, int type) {
   }
 
   control->scgi()->set_slot_process(rak::mem_fn(&rpc::xmlrpc, &rpc::XmlRpc::process));
+  control->scgi()->activate();
 }
 
 void
@@ -492,6 +493,6 @@ initialize_command_network() {
   ADD_VARIABLE_BOOL("peer_exchange", true);
 
   // Not really network stuff:
-  ADD_VARIABLE_BOOL("handshake_log", false);
-  ADD_VARIABLE_STRING("tracker_dump", "");
+  ADD_VARIABLE_BOOL  ("handshake_log", false);
+  ADD_VARIABLE_STRING("log.tracker", "");
 }
