@@ -101,6 +101,7 @@ private:
   bool                m_session;
   bool                m_start;
   bool                m_printLog;
+  bool                m_isFile;
 
   command_list_type         m_commands;
   torrent::Object::map_type m_variables;
@@ -110,6 +111,8 @@ private:
   rak::priority_item  m_taskCommit;
 };
 
+bool is_network_uri(const std::string& uri);
+
 }
 
 #endif
