@@ -82,7 +82,10 @@ DownloadList::clear() {
 
 void
 DownloadList::session_save() {
-  std::for_each(begin(), end(), std::bind1st(std::mem_fun(&DownloadStore::save), control->core()->download_store()));
+  unsigned int c = std::count_if(begin(), end(), std::bind1st(std::mem_fun(&DownloadStore::save), control->core()->download_store()));
+
+  if (c != size())
+    control->core()->push_log("Failed to save session torrents.");
 
   control->dht_manager()->save_dht_cache();
 }
@@ -468,6 +471,7 @@ DownloadList::hash_done(Download* download) {
 
     if (rpc::call_command_value("d.get_state", rpc::make_target(download)) == 1)
       resume(download, download->resume_flags());
+    //rpc::commands.call_catch("scheduler.simple.resume", rpc::make_target(download), torrent::Object(), "Download event action failed: ");
 
     break;
 
