@@ -77,7 +77,7 @@ namespace core {
 
 void
 receive_tracker_dump(const std::string& url, const char* data, size_t size) {
-  const std::string& filename = rpc::call_command_string("get_tracker_dump");
+  const std::string& filename = rpc::call_command_string("get_log.tracker");
 
   if (filename.empty())
     return;
@@ -158,10 +158,9 @@ Manager::push_log(const char* msg) {
 }
 
 Manager::Manager() :
-  m_hashingView(NULL),
-
-  m_pollManager(NULL) {
-
+  m_hashingView(NULL)
+//   m_pollManager(NULL) {
+{
   m_downloadStore   = new DownloadStore();
   m_downloadList    = new DownloadList();
   m_fileStatusCache = new FileStatusCache();
@@ -216,40 +215,6 @@ Manager::get_address_throttle(const sockaddr* addr) {
   return m_addressThrottles.get(rak::socket_address::cast_from(addr)->sa_inet()->address_h(), torrent::ThrottlePair(NULL, NULL));
 }
 
-void
-Manager::initialize_first() {
-  const char* poll = getenv("RTORRENT_POLL");
-  if (poll != NULL) {
-    if (!strcmp(poll, "epoll"))
-      m_pollManager = PollManagerEPoll::create(sysconf(_SC_OPEN_MAX));
-    else if (!strcmp(poll, "kqueue"))
-      m_pollManager = PollManagerKQueue::create(sysconf(_SC_OPEN_MAX));
-    else if (!strcmp(poll, "select"))
-      m_pollManager = PollManagerSelect::create(sysconf(_SC_OPEN_MAX));
-
-    if (m_pollManager == NULL)
-      m_logImportant.push_front(std::string("Cannot enable '") + poll + "' based polling.");
-  }
-
-  if (m_pollManager != NULL)
-      m_logImportant.push_front(std::string("Using '") + poll + "' based polling.");
-
-  else if ((m_pollManager = PollManagerEPoll::create(sysconf(_SC_OPEN_MAX))) != NULL)
-    m_logImportant.push_front("Using 'epoll' based polling.");
-
-  else if ((m_pollManager = PollManagerKQueue::create(sysconf(_SC_OPEN_MAX))) != NULL)
-    m_logImportant.push_front("Using 'kqueue' based polling.");
-
-  else if ((m_pollManager = PollManagerSelect::create(sysconf(_SC_OPEN_MAX))) != NULL)
-    m_logImportant.push_front("Using 'select' based polling.");
-
-  else
-    throw std::runtime_error("Could not create any PollManager.");
-
-  // Need to initialize this before parseing options.
-  torrent::initialize(m_pollManager->get_torrent_poll());
-}
-
 // Most of this should be possible to move out.
 void
 Manager::initialize_second() {
@@ -276,7 +241,6 @@ Manager::cleanup() {
   delete m_httpStack;
   CurlStack::global_cleanup();
 
-  delete m_pollManager;
 }
 
 void
