@@ -42,3 +42,5 @@ rak::priority_queue_default taskScheduler;
 rak::timer                  cachedTime;
 
 Control*                    control = NULL;
+//__thread ThreadBase* this_thread = NULL;
+ThreadBase* this_thread = NULL;
