@@ -75,9 +75,9 @@ SCgiTask::open(SCgi* parent, int fd) {
   m_position = m_buffer;
   m_body     = NULL;
 
-  control->poll()->open(this);
-  control->poll()->insert_read(this);
-  control->poll()->insert_error(this);
+  this_thread->poll()->open(this);
+  this_thread->poll()->insert_read(this);
+  this_thread->poll()->insert_error(this);
 
 //   scgiTimer = rak::timer::current();
 }
@@ -87,10 +87,10 @@ SCgiTask::close() {
   if (!get_fd().is_valid())
     return;
 
-  control->poll()->remove_read(this);
-  control->poll()->remove_write(this);
-  control->poll()->remove_error(this);
-  control->poll()->close(this);
+  this_thread->poll()->remove_read(this);
+  this_thread->poll()->remove_write(this);
+  this_thread->poll()->remove_error(this);
+  this_thread->poll()->close(this);
 
   get_fd().close();
   get_fd().clear();
@@ -171,8 +171,15 @@ SCgiTask::event_read() {
   if ((unsigned int)std::distance(m_buffer, m_position) != m_bufferSize)
     return;
 
-  control->poll()->remove_read(this);
-  control->poll()->insert_write(this);
+  this_thread->poll()->remove_read(this);
+  this_thread->poll()->insert_write(this);
+
+  if (m_parent->log_fd() >= 0) {
+    // Clean up logging, this is just plain ugly...
+    //    write(m_logFd, "\n---\n", sizeof("\n---\n"));
+    write(m_parent->log_fd(), m_buffer, m_bufferSize);
+    write(m_parent->log_fd(), "\n---\n", sizeof("\n---\n"));
+  }
 
   // Close if the call failed, else stay open to write back data.
   if (!m_parent->receive_call(this, m_body, m_bufferSize - std::distance(m_buffer, m_body)))
